---
name: Command Request
about: Guideline for requesting Commands.
title: "[Command]"
labels: Bug, Command Request
assignees: ''

---

- [ ] I have verified this command does not currently exist.
### Reason for request:
*Short summary as to why you believe this command would benefit HangoutCore Users.*

# Commands:
###### Command Category:
- [ ] **Command Name** (arg1) (arg2) (arg1: content[^argdependant]):
- *Command Description...*

[^argdependant]:
    This argument is only relevant if the arg specified is present.
    ie; (arg1) (arg2) (arg1: info) | *Info* is only processed when the user passes **arg1**, otherwise it's not used by the bot.
